pub fn prim_current_node(args: &[Value]) -> PrimitiveResultExpand description
(current-node) → node
Returns the current node being processed.
In DSSSL, the current node is an implicit context variable that changes as the evaluator processes the document tree. When processing children or a node-list, the current-node changes to each node in turn.
DSSSL: Grove primitive (context-dependent)